@@ -4,6 +4,7 @@
 /* params - example program to create RaptorQ context and print derived parameters */
 
 #include <lcrq.h>
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -37,7 +38,7 @@ int main(int argc, char *argv[])
 	/* free RaptorQ context */
 	rq_free(rq);
 
-	printf("F  %12lu\tsize of object to encode (40 bits)\n", F);
+	printf("F  %12" PRIu64 "\tsize of object to encode (40 bits)\n", F);
 	printf("T  %12u\tsymbol (payload) size\n", T);
 	printf("K  %12u\tnumber of original symbols\n", K);
 	printf("K' %12u\tnumber of symbols, including padding symbols\n", KP);
