@@ -1,8 +1,13 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only */
-/* Copyright (c) 2022-2024 Brett Sheffield <bacs@librecast.net> */
+/* Copyright (c) 2022-2025 Brett Sheffield <bacs@librecast.net> */
 
 #include <gf256.h>
 
+#if (defined(INTEL_AVX2) || defined(INTEL_SSSE3))
+/* left-right table for GF256 lookups */
+uint8_t GF256LR[256][2][16];
+#endif
+
 uint8_t gf256_add(const uint8_t a, const uint8_t b)
 {
 	return a ^ b;
@@ -39,5 +44,6 @@ uint8_t gf256_div(const uint8_t u, const uint8_t v)
 }
 
 #if USE_NATIVE
+# include "gf256_avx2.c"
 # include "gf256_ssse3.c"
 #endif
