@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only */
-/* Copyright (c) 2022 Brett Sheffield <bacs@librecast.net> */
+/* Copyright (c) 2022-2025 Brett Sheffield <bacs@librecast.net> */
 
 #ifndef GF256_H
 #define GF256_H
@@ -122,7 +122,12 @@ uint8_t gf256_mul(const uint8_t a, const uint8_t b);
 uint8_t gf256_div(const uint8_t u, const uint8_t v);
 
 #ifdef USE_SIMD_x86
+__m512i gf256_mul_512(__m512i A, uint8_t y);
+void gf256_mul_512_inplace(uint8_t *d, uint8_t y);
+__m256i gf256_mul_256(__m256i A, uint8_t y);
+void gf256_mul_256_inplace(uint8_t *d, uint8_t y);
 __m128i gf256_mul_128(__m128i A, uint8_t y);
+void gf256_mul_128_inplace(uint8_t *d, uint8_t y);
 #endif
 
 void gf256_init(void);
