@@ -1,10 +1,8 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only */
-/* Copyright (c) 2022-2024 Brett Sheffield <bacs@librecast.net> */
+/* Copyright (c) 2022-2025 Brett Sheffield <bacs@librecast.net> */
 
 #include <gf256.h>
 
-uint8_t GF256LR[256][2][16];
-
 /*
  * Method adapted from the technique described in:
  * J. S. Plank and K. M. Greenan and E. L. Miller (2013)
@@ -29,6 +27,13 @@ __m128i gf256_mul_128(__m128i A, uint8_t y)
 	return _mm_xor_si128(h, l);
 }
 
+void gf256_mul_128_inplace(uint8_t *d, uint8_t y)
+{
+	__m128i D = _mm_loadu_si128((const __m128i_u *)d);
+	D = gf256_mul_128(D, y);
+	_mm_storeu_si128((__m128i*)d, D);
+}
+
 /* allocate and precompute tables */
 void gf256_init(void)
 {
