@@ -23,9 +23,7 @@
 # define be32toh(x) OSSwapBigToHostInt32(x)
 #endif
 
-#if (defined(HAVE_LIBSODIUM))
-# include <sodium.h>
-#elif (defined(HAVE_GETRANDOM))
+#if (defined(HAVE_GETRANDOM))
 # include <sys/random.h>
 #else
 # include <fcntl.h>
@@ -167,9 +165,7 @@ static uint32_t rq_random_esi(uint32_t min)
 {
 	/* NB: ESI is a 24-bit unsigned integer (3.2) */
 	uint32_t esi = UINT32_MAX;
-#ifdef HAVE_LIBSODIUM
-	esi = randombytes_uniform(RQ_ESI_MAX - min) + min;
-#elif defined (HAVE_ARC4RANDOM_UNIFORM)
+#if defined (HAVE_ARC4RANDOM_UNIFORM)
 	esi = arc4random_uniform(RQ_ESI_MAX - min) + min;
 #else
 	/* read 24 bits (3 bytes) from /dev/random */
