@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only */
-/* Copyright (c) 2022-2024 Brett Sheffield <bacs@librecast.net> */
+/* Copyright (c) 2022-2025 Brett Sheffield <bacs@librecast.net> */
 
 #include <matrix.h>
 #include <gf256.h>
@@ -20,9 +20,14 @@ static void matrix_row_mul_byrow_dispatch(matrix_t *m, const int rdst, const int
 void (*matrix_row_mul_byrow)(matrix_t *, const int, const int, const int, const uint8_t) = &matrix_row_mul_byrow_dispatch;
 
 #if !(USE_NATIVE)
+void matrix_row_add_avx512(matrix_t *dst, const int drow, const matrix_t *src, const int srow);
 void matrix_row_add_avx2(matrix_t *dst, const int drow, const matrix_t *src, const int srow);
 void matrix_row_add_sse2(matrix_t *dst, const int drow, const matrix_t *src, const int srow);
+void matrix_row_mul_avx512(matrix_t *m, const int row, const int off, const uint8_t y);
+void matrix_row_mul_avx2(matrix_t *m, const int row, const int off, const uint8_t y);
 void matrix_row_mul_ssse3(matrix_t *m, const int row, const int off, const uint8_t y);
+void matrix_row_mul_byrow_avx512(matrix_t *m, const int rdst, const int off, const int rsrc, const uint8_t y);
+void matrix_row_mul_byrow_avx2(matrix_t *m, const int rdst, const int off, const int rsrc, const uint8_t y);
 void matrix_row_mul_byrow_ssse3(matrix_t *m, const int rdst, const int off, const int rsrc, const uint8_t y);
 #endif /* USE_NATIVE */
 
@@ -258,6 +263,7 @@ matrix_t *matrix_swap_cols(matrix_t *m, const int c1, const int c2)
 	return m;
 }
 #if USE_NATIVE
+# include "matrix_avx512.c"
 # include "matrix_avx2.c"
 # include "matrix_ssse3.c"
 # include "matrix_sse2.c"
@@ -293,8 +299,9 @@ static void matrix_row_add_dispatch(matrix_t *dst, const int drow, const matrix_
 	matrix_row_add = &matrix_row_add_nosimd;
 #ifdef USE_SIMD_x86
 	const int isets = cpu_instruction_set();
-	if      (isets & AVX2) matrix_row_add = &matrix_row_add_avx2;
-	else if (isets & SSE2) matrix_row_add = &matrix_row_add_sse2;
+	if      (isets & AVX512F) matrix_row_add = &matrix_row_add_avx512;
+	else if (isets & AVX2)    matrix_row_add = &matrix_row_add_avx2;
+	else if (isets & SSE2)    matrix_row_add = &matrix_row_add_sse2;
 #endif
 	matrix_row_add(dst, drow, src, srow);
 }
@@ -304,7 +311,10 @@ static void matrix_row_mul_dispatch(matrix_t *m, const int row, const int off, c
 	matrix_row_mul = &matrix_row_mul_nosimd;
 #ifdef USE_SIMD_x86
 	const int isets = cpu_instruction_set();
-	if (isets & SSSE3) matrix_row_mul = &matrix_row_mul_ssse3;
+	if (isets & (AVX512F|AVX512DQ|AVX512BW))
+				matrix_row_mul = &matrix_row_mul_avx512;
+	else if (isets & AVX2)	matrix_row_mul = &matrix_row_mul_avx2;
+	else if (isets & SSSE3)	matrix_row_mul = &matrix_row_mul_ssse3;
 #endif
 	matrix_row_mul(m, row, off, y);
 }
@@ -314,7 +324,10 @@ static void matrix_row_mul_byrow_dispatch(matrix_t *m, const int rdst, const int
 	matrix_row_mul_byrow = &matrix_row_mul_byrow_nosimd;
 #ifdef USE_SIMD_x86
 	const int isets = cpu_instruction_set();
-	if (isets & SSSE3) matrix_row_mul_byrow = &matrix_row_mul_byrow_ssse3;
+	if (isets & (AVX512F|AVX512DQ|AVX512BW))
+				matrix_row_mul_byrow = &matrix_row_mul_byrow_avx512;
+	else if (isets & AVX2)	matrix_row_mul_byrow = &matrix_row_mul_byrow_avx2;
+	else if (isets & SSSE3)	matrix_row_mul_byrow = &matrix_row_mul_byrow_ssse3;
 #endif
 	matrix_row_mul_byrow(m, rdst, off, rsrc, y);
 }
