@@ -1,22 +1,18 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only */
-/* Copyright (c) 2020-2023 Brett Sheffield <bacs@librecast.net> */
+/* Copyright (c) 2020-2025 Brett Sheffield <bacs@librecast.net> */
 
 #include "test.h"
-#include <fcntl.h>
+#include <pthread.h>
 #include <semaphore.h>
 #include <stdlib.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
-#include <time.h>
-#include <sys/time.h>
 #include <sys/resource.h>
 #include <unistd.h>
-#ifdef HAVE_SYS_RANDOM_H
-# include <sys/random.h>
-#endif
 
 #define DEFAULT_TERM_COLS 80
 #define TESTID_WIDTH 16
+#define SPINAL_TAP 11
 
 int COLS = DEFAULT_TERM_COLS;
 int MSGW;
@@ -25,38 +21,65 @@ int capreqd = 0;
 int capfail = 0;
 sem_t log_lock;
 
+static int _vscprintf (const char * format, va_list argp)
+{
+	int r;
+	va_list argc;
+	va_copy(argc, argp);
+	r = vsnprintf(NULL, 0, format, argc);
+	va_end(argc);
+	return r;
+}
+
 void vfail_msg(char *msg, va_list argp)
 {
 	char *b;
 	b = malloc(_vscprintf(msg, argp) + 1);
+	pthread_cleanup_push(free, b);
 	vsprintf(b, msg, argp);
-	printf("\n            %-*s", MSGW, b);
-	free(b);
+	printf("\n%-*s%-*s", SPINAL_TAP, " ", MSGW, b);
+	pthread_cleanup_pop(1); /* free(b); */
 	test_status = TEST_FAIL;
 }
 
-void fail_msg(char *msg, ...)
+static int test_assert_va(int condition, int verbose, char *msg, va_list argp)
 {
-	va_list argp;
-	va_start(argp, msg);
-	vfail_msg(msg, argp);
+	char *b;
+	va_list copy;
+	va_copy(copy, argp);
+	b = malloc(_vscprintf(msg, argp) + 6);
+	pthread_cleanup_push(free, b);
+	if (b) vsprintf(b, msg, copy);
+	if (!condition) {
+		vfail_msg(msg, argp);
+		if (b) test_log("[FAIL] %s\n", b);
+	}
+	else if (b && verbose) {
+		test_log("[ OK ] %s\n", b);
+	}
+	pthread_cleanup_pop(1); /* free(b); */
 	va_end(argp);
+	return condition;
 }
 
 int test_assert(int condition, char *msg, ...)
 {
-	if (!condition) {
-		va_list argp;
-		va_start(argp, msg);
-		vfail_msg(msg, argp);
-		va_end(argp);
-	}
-	return condition;
+	va_list argp;
+	va_start(argp, msg);
+	return test_assert_va(condition, 1, msg, argp);
 }
 
-void test_assert_s(int condition)
+int test_assert_s(int condition)
 {
-	test_assert(condition, "test");
+	return test_assert(condition, "test");
+}
+
+/* assert quietly - only log on failure */
+int test_assert_q(int condition, char *msg, ...)
+{
+	va_list argp;
+	va_start(argp, msg);
+	return test_assert_va(condition, 0, msg, argp);
 }
 
 int test_strcmp(char *str1, char *str2, char *msg, ...)
@@ -99,13 +122,23 @@ void test_log(char *msg, ...)
 	va_list argp;
 	va_start(argp, msg);
 	b = malloc(_vscprintf(msg, argp) + 1);
+	pthread_cleanup_push(free, b);
 	vsprintf(b, msg, argp);
-	sem_wait(&log_lock);
-	fprintf(stderr, "%s\n", b);
+
+	/* In order to keep the test logs clean we try to wait for other threads
+	 * to finish before logging, but if we need to wait more than a second,
+	 * give up and log anyway. A deadlock between two test threads is best
+	 * avoided. */
+	struct timespec ts;
+	clock_gettime(CLOCK_REALTIME, &ts);
+	ts.tv_sec++;
+	sem_timedwait(&log_lock, &ts);
+
+	fprintf(stderr, "%s", b);
 	fflush(stderr);
 	sem_post(&log_lock);
 	va_end(argp);
-	free(b);
+	pthread_cleanup_pop(1); /* free(b); */
 }
 
 static void init_terminal(void)
@@ -121,29 +154,43 @@ static void init_terminal(void)
 	MSGW = COLS - TESTID_WIDTH;
 }
 
+void test_init(void)
+{
+	static int runonce;
+	if (runonce++) return;
+	init_terminal();
+	sem_init(&log_lock, 0, 1);
+}
+
 void test_name(char *str, ...)
 {
 	char *b;
 	va_list argp;
+	int do_exit = 1;
 
-	init_terminal();
-	sem_init(&log_lock, 0, 1);
-	if (capfail) {
-		printf("%-*s", MSGW, "----- requires capabilities (skipping) -----");
-		exit(test_status);
-	}
-	else if (!capreqd && geteuid() == 0) {
-		printf("%-*s", MSGW, "----- does not require root (skipping) -----");
-		exit(test_status);
-	}
+	test_init();
 	va_start(argp, str);
 	b = malloc(_vscprintf(str, argp) + 1);
 	vsprintf(b, str, argp);
-	test_log("  (%s)", b);
-	printf("%-*s", MSGW, b);
-	fflush(stdout);
+	test_log("  %s\n", b);
+	test_log("\n");
+	if (capfail) {
+		printf("%-*s", MSGW, "----- requires capabilities (skipping) -----");
+	}
+	else if (!capreqd && geteuid() == 0) {
+		printf("%-*s", MSGW, "----- does not require root (skipping) -----");
+	}
+	else if (test_status != TEST_OK) {
+		printf("%-*s", MSGW, "----- (skipping) -----");
+	}
+	else {
+		printf("%-*s", MSGW, b);
+		do_exit ^= do_exit;
+	}
+	fflush(stdout); /* ensure the test name is displayed in case of SIGABORT */
 	va_end(argp);
 	free(b);
+	if (do_exit) exit(test_status);
 }
 
 int test_skip(char *str, ...)
@@ -157,27 +204,11 @@ int test_skip(char *str, ...)
 	b = malloc(_vscprintf(str, argp) + 1);
 	vsprintf(b, str, argp);
 	printf("(skipped) %-*s", MSGW - 10, b);
-	test_log("  (%s)", b);
+	test_log("  %s\n", b);
+	test_log("\n");
 	va_end(argp);
 	free(b);
-	return 0;
-}
-
-void test_cap_require(int cap)
-{
-	(void) cap;
-	// TODO check for capabilities on Linux
-	if (geteuid()) capfail++;
-	capreqd++;
-}
-
-void test_require_linux(void)
-{
-#ifndef __linux__
-	init_terminal();
-	printf("%-*s", MSGW, "----- linux only (skipping) -----");
-	exit(test_status);
-#endif
+	return TEST_WARN;
 }
 
 void test_rusage(void)
@@ -205,22 +236,19 @@ void test_rusage(void)
 	test_log("nivcsw:   %li\n", ru.ru_nivcsw);
 }
 
-#ifndef HAVE_LIBSODIUM
-void test_randombytes(void *buf, size_t len)
+void test_cap_require(int cap)
 {
-	ssize_t return_ignored;
-#if defined(HAVE_GETRANDOM) && defined(HAVE_SYS_RANDOM_H)
-	return_ignored = getrandom(buf, len, 0);
-#else
-	static int f; /* we'll keep the handle until program exit */
-	if (!f) f = open("/dev/urandom", O_RDONLY);
-	return_ignored = read(f, buf, len);
-#endif
-	(void)return_ignored;
+	(void) cap;
+	// TODO check for capabilities on Linux
+	if (geteuid()) capfail++;
+	capreqd++;
 }
 
-uint32_t test_randomnumber(const uint32_t upper_bound)
+void test_require_linux(void)
 {
-	return (uint32_t)random() % upper_bound;
-}
+#ifndef __linux__
+	init_terminal();
+	printf("%-*s", MSGW, "----- linux only (skipping) -----");
+	exit(test_status);
 #endif
+}
